@@ -1,7 +1,7 @@
 # urwid user interface for reportbug
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   (C) 2006-08 Chris Lawrence
-#   Copyright (C) 2008-2010 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2011 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -49,7 +49,6 @@ except ImportError:
 ISATTY = sys.stdin.isatty()
 
 log_message = ewrite
-display_failure = ewrite
 
 # Start a urwid session
 def initialize_urwid_ui():
@@ -323,6 +322,7 @@ def long_message(message, *args, **kwargs):
 
 final_message = long_message
 display_report = long_message
+display_failure = long_message
 
 def select_options(msg, ok, help=None, allow_numbers=False, nowrap=False,
                    ui=None, title=None):
@@ -532,7 +532,8 @@ def show_report(number, system, mirrors,
 
 def handle_bts_query(package, bts, timeout, mirrors=None, http_proxy="",
                      queryonly=False, screen=None, title="", archived='no',
-                     source=False, version=None, mbox=False, buglist=None):
+                     source=False, version=None, mbox=False, buglist=None,
+                     mbox_reader_cmd=None):
     from reportbug import debianbts
 
     sysinfo = debianbts.SYSTEMS[bts]
